@@ -420,6 +420,11 @@ function SelectLanguage()
   var item = gDialog.LanguageMenulist.selectedItem;
   if (item.value != "more-cmd") {
     gSpellChecker.SetCurrentDictionary(item.value);
+    // For compose windows we need to set the "lang" attribute so the
+    // core editor uses the correct dictionary for the inline spell check.
+    if (window.arguments[1]) {
+      window.opener.document.documentElement.setAttribute("lang", item.value);
+    }
     gLastSelectedLang = item;
   }
   else {
