@@ -12,10 +12,17 @@ var abList = 0;
 var gAbResultsTree = null;
 var gAbView = null;
 var gAddressBookBundle;
+// A boolean variable determining whether AB column should be shown in AB
+// sidebar in compose window.
+var gShowAbColumnInComposeSidebar = false;
 
 const kDefaultSortColumn = "GeneratedName";
 const kDefaultAscending = "ascending";
 const kDefaultDescending = "descending";
+// kDefaultYear will be used in birthday calculations when no year is given;
+// this is a leap year so that Feb 29th works.
+const kDefaultYear = 2000;
+const kAllDirectoryRoot = "moz-abdirectory://";
 const kLdapUrlPrefix = "moz-abldapdirectory://";
 const kPersonalAddressbookURI = "moz-abmdbdirectory://abook.mab";
 const kCollectedAddressbookURI = "moz-abmdbdirectory://history.mab";
@@ -39,6 +46,7 @@ var DirPaneController =
       case "cmd_printcard":
       case "cmd_printcardpreview":
       case "cmd_newlist":
+      case "cmd_newCard":
         return true;
       default:
         return false;
@@ -65,8 +73,9 @@ var DirPaneController =
                                   "valueList" : "valueAddressBook");
 
         if (selectedDir &&
-	    (selectedDir != kPersonalAddressbookURI) &&
-	    (selectedDir != kCollectedAddressbookURI)) {
+            (selectedDir != kPersonalAddressbookURI) &&
+            (selectedDir != kCollectedAddressbookURI) &&
+            (selectedDir != (kAllDirectoryRoot + "?"))) {
           // If the directory is a mailing list, and it is read-only, return
           // false.
           var abDir = GetDirectoryFromURI(selectedDir);
@@ -100,13 +109,16 @@ var DirPaneController =
         return (GetSelectedDirectory() != null);
       case "cmd_newlist":
         selectedDir = GetSelectedDirectory();
-        if (selectedDir) {
+        if (selectedDir && selectedDir != (kAllDirectoryRoot + "?")) {
           var abDir = GetDirectoryFromURI(selectedDir);
           if (abDir) {
             return abDir.supportsMailingLists;
           }
         }
         return false;
+      case "cmd_newCard":
+        selectedDir = GetSelectedDirectory();
+        return (selectedDir && selectedDir != (kAllDirectoryRoot + "?"));
       default:
         return false;
     }
@@ -131,6 +143,9 @@ var DirPaneController =
       case "cmd_newlist":
         AbNewList();
         break;
+      case "cmd_newCard":
+        AbNewCard();
+        break;
     }
   },
 
@@ -255,6 +270,14 @@ function InitCommonJS()
   gDirTree = document.getElementById("dirTree");
   abList = document.getElementById("addressbookList");
   gAddressBookBundle = document.getElementById("bundle_addressBook");
+
+  // Make an entry for "All Address Books".
+  if (abList) {
+    abList.insertItemAt(0, gAddressBookBundle.getString("allAddressBooks"),
+                        kAllDirectoryRoot + "?");
+    // Select the newly added entry.
+    abList.selectedIndex = 0;
+  }
 }
 
 function AbDelete()
@@ -279,8 +302,28 @@ function AbDelete()
       confirmDeleteMessage = gAddressBookBundle.getString("confirmDeleteContacts");
   }
 
-  if (confirmDeleteMessage && Services.prompt.confirm(window, null, confirmDeleteMessage))
-    gAbView.deleteSelectedCards();
+  if (confirmDeleteMessage &&
+      Services.prompt.confirm(window, null, confirmDeleteMessage)) {
+    if (GetSelectedDirectory() != (kAllDirectoryRoot + "?")) {
+      gAbView.deleteSelectedCards();
+    } else {
+      let cards = GetSelectedAbCards();
+      for (let i = 0; i < cards.length; i++) {
+        let dirId = cards[i].directoryId
+                            .substring(0, cards[i].directoryId.indexOf("&"));
+        let directory = MailServices.ab.getDirectoryFromId(dirId);
+
+        let cardArray =
+          Components.classes["@mozilla.org/array;1"]
+                    .createInstance(Components.interfaces.nsIMutableArray);
+        cardArray.appendElement(cards[i], false);
+        if (directory)
+          directory.deleteCards(cardArray);
+      }
+
+      SetAbView(kAllDirectoryRoot + "?");
+    }
+  }
 }
 
 function AbNewCard()
@@ -449,13 +492,20 @@ function DirPaneDoubleClick(event)
 
 function DirPaneSelectionChange()
 {
+  let uri = GetSelectedDirectory();
   // clear out the search box when changing folders...
   onAbClearSearch();
   if (gDirTree && gDirTree.view.selection && gDirTree.view.selection.count == 1) {
     gPreviousDirTreeIndex = gDirTree.currentIndex;
-    ChangeDirectoryByURI(GetSelectedDirectory());
+    ChangeDirectoryByURI(uri);
+    document.getElementById("localResultsOnlyMessage")
+            .setAttribute("hidden",
+                          !gDirectoryTreeView.hasRemoteAB ||
+                          uri != kAllDirectoryRoot + "?");
   }
+
   goUpdateCommand('cmd_newlist');
+  goUpdateCommand('cmd_newCard');
 }
 
 function ChangeDirectoryByURI(uri = kPersonalAddressbookURI)
@@ -495,7 +545,7 @@ function goEditListDialog(abCard, listURI)
                     "chrome,modal,resizable=no,centerscreen",
                     params);
   if (params.refresh) {
-    ChangeDirectoryByURI(listUri); // force refresh
+    ChangeDirectoryByURI(listURI); // force refresh
   }
 }
 
@@ -661,6 +711,10 @@ function getSearchTokens(aSearchString)
  */
 function generateQueryURI(aModelQuery, aSearchWords)
 {
+  // If there are no search tokens, we simply return an empty string.
+  if (!aSearchWords || aSearchWords.length == 0)
+    return "";
+
   let queryURI = "";
   aSearchWords.forEach(searchWord =>
     queryURI += aModelQuery.replace(/@V/g, encodeABTermValue(searchWord)));
@@ -676,6 +730,7 @@ function onAbClearSearch()
   var searchInput = document.getElementById("peopleSearchInput");
   if (searchInput)
     searchInput.value = "";
+
   onEnterInSearchBar();
 }
 
@@ -845,3 +900,11 @@ function encodeABTermValue(aString) {
   return encodeURIComponent(aString).replace(/\(/g, "%28").replace(/\)/g, "%29");
 }
 
+/**
+ * Validates the given year and returns it, if it looks sane.
+ * Returns kDefaultYear (a leap year), if no valid date is given.
+ * This ensures that month/day calculations still work.
+ */
+function saneBirthYear(aYear) {
+  return aYear && aYear < 10000 && aYear > 0 ? aYear : kDefaultYear;
+}
