@@ -12,7 +12,6 @@
 #include "nsIServiceManager.h"
 #include "nsCOMPtr.h"
 #include "nsStringGlue.h"
-#include "nsISupportsObsolete.h"
 #include "nsISupportsPrimitives.h"
 
 #include "nsMsgBaseCID.h"
@@ -54,6 +53,7 @@
 
 nsMsgIncomingServer::nsMsgIncomingServer():
     m_rootFolder(0),
+    m_downloadedHdrs(50),
     m_numMsgsDownloaded(0),
     m_biffState(nsIMsgFolder::nsMsgBiffState_Unknown),
     m_serverBusy(false),
@@ -61,20 +61,14 @@ nsMsgIncomingServer::nsMsgIncomingServer():
     m_displayStartupPage(true),
     mPerformingBiff(false)
 { 
-  m_downloadedHdrs.Init(50);
 }
 
 nsMsgIncomingServer::~nsMsgIncomingServer()
 {
 }
 
-NS_IMPL_THREADSAFE_ADDREF(nsMsgIncomingServer)
-NS_IMPL_THREADSAFE_RELEASE(nsMsgIncomingServer)
-NS_INTERFACE_MAP_BEGIN(nsMsgIncomingServer)
-    NS_INTERFACE_MAP_ENTRY(nsIMsgIncomingServer)
-    NS_INTERFACE_MAP_ENTRY(nsISupportsWeakReference)
-    NS_INTERFACE_MAP_ENTRY_AMBIGUOUS(nsISupports, nsIMsgIncomingServer)
-NS_INTERFACE_MAP_END_THREADSAFE
+NS_IMPL_ISUPPORTS(nsMsgIncomingServer, nsIMsgIncomingServer,
+  nsISupportsWeakReference)
 
 NS_IMETHODIMP
 nsMsgIncomingServer::SetServerBusy(bool aServerBusy)
@@ -789,7 +783,7 @@ nsMsgIncomingServer::GetPasswordWithUI(const nsAString& aPromptMessage, const
       // we pass in the previously used password, if any, into PromptPassword
       // so that it will appear as ******. This means we can't use an nsString
       // and getter_Copies.
-      PRUnichar *uniPassword = nullptr;
+      char16_t *uniPassword = nullptr;
       if (!aPassword.IsEmpty())
         uniPassword = ToNewUnicode(NS_ConvertASCIItoUTF16(aPassword));
 
@@ -885,7 +879,7 @@ nsMsgIncomingServer::SetDefaultLocalPath(nsIFile *aDefaultLocalPath)
 {
   nsresult rv;
   nsCOMPtr<nsIMsgProtocolInfo> protocolInfo;
-  rv = getProtocolInfo(getter_AddRefs(protocolInfo));
+  rv = GetProtocolInfo(getter_AddRefs(protocolInfo));
   NS_ENSURE_SUCCESS(rv, rv);
   return protocolInfo->SetDefaultLocalPath(aDefaultLocalPath);
 }
@@ -905,7 +899,7 @@ nsMsgIncomingServer::GetLocalPath(nsIFile **aLocalPath)
   // hostname, unless that directory exists.
 // this should prevent all collisions.
   nsCOMPtr<nsIMsgProtocolInfo> protocolInfo;
-  rv = getProtocolInfo(getter_AddRefs(protocolInfo));
+  rv = GetProtocolInfo(getter_AddRefs(protocolInfo));
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCOMPtr<nsIFile> localPath;
@@ -949,6 +943,11 @@ nsMsgIncomingServer::GetMsgStore(nsIMsgPluggableStore **aMsgStore)
       storeContractID.Assign("@mozilla.org/msgstore/berkeleystore;1");
       SetCharValue("storeContractID", storeContractID);
     }
+
+    // After someone starts using the pluggable store, we can no longer
+    // change the value.
+    SetBoolValue("canChangeStoreType", false);
+
     // Right now, we just have one pluggable store per server. If we want
     // to support multiple, this pref could be a list of pluggable store
     // contract id's.
@@ -959,7 +958,6 @@ nsMsgIncomingServer::GetMsgStore(nsIMsgPluggableStore **aMsgStore)
   return NS_OK;
 }
 
-
 NS_IMETHODIMP
 nsMsgIncomingServer::SetLocalPath(nsIFile *aLocalPath)
 {
@@ -1357,7 +1355,7 @@ nsMsgIncomingServer::GetDoBiff(bool *aDoBiff)
   // if the pref isn't set, use the default
   // value based on the protocol
   nsCOMPtr<nsIMsgProtocolInfo> protocolInfo;
-  rv = getProtocolInfo(getter_AddRefs(protocolInfo));
+  rv = GetProtocolInfo(getter_AddRefs(protocolInfo));
   NS_ENSURE_SUCCESS(rv, rv);
 
   rv = protocolInfo->GetDefaultDoBiff(aDoBiff);
@@ -1393,7 +1391,7 @@ nsMsgIncomingServer::GetPort(int32_t *aPort)
   // if the port isn't set, use the default
   // port based on the protocol
   nsCOMPtr<nsIMsgProtocolInfo> protocolInfo;
-  rv = getProtocolInfo(getter_AddRefs(protocolInfo));
+  rv = GetProtocolInfo(getter_AddRefs(protocolInfo));
   NS_ENSURE_SUCCESS(rv, rv);
 
   int32_t socketType;
@@ -1409,7 +1407,7 @@ nsMsgIncomingServer::SetPort(int32_t aPort)
   nsresult rv;
 
   nsCOMPtr<nsIMsgProtocolInfo> protocolInfo;
-  rv = getProtocolInfo(getter_AddRefs(protocolInfo));
+  rv = GetProtocolInfo(getter_AddRefs(protocolInfo));
   NS_ENSURE_SUCCESS(rv, rv);
 
   int32_t socketType;
@@ -1422,14 +1420,13 @@ nsMsgIncomingServer::SetPort(int32_t aPort)
   return SetIntValue("port", aPort == defaultPort ? PORT_NOT_SET : aPort);
 }
 
-nsresult
-nsMsgIncomingServer::getProtocolInfo(nsIMsgProtocolInfo **aResult)
+NS_IMETHODIMP
+nsMsgIncomingServer::GetProtocolInfo(nsIMsgProtocolInfo **aResult)
 {
   NS_ENSURE_ARG_POINTER(aResult);
-  nsresult rv;
 
   nsCString type;
-  rv = GetType(type);
+  nsresult rv = GetType(type);
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsAutoCString contractid(NS_MSGPROTOCOLINFO_CONTRACTID_PREFIX);
@@ -1437,7 +1434,8 @@ nsMsgIncomingServer::getProtocolInfo(nsIMsgProtocolInfo **aResult)
 
   nsCOMPtr<nsIMsgProtocolInfo> protocolInfo = do_GetService(contractid.get(), &rv);
   NS_ENSURE_SUCCESS(rv, rv);
-  protocolInfo.swap(*aResult);
+
+  protocolInfo.forget(aResult);
   return NS_OK;
 }
 
@@ -1622,11 +1620,11 @@ NS_IMETHODIMP nsMsgIncomingServer::DisplayOfflineMsg(nsIMsgWindow *aMsgWindow)
   {
     nsString errorMsgTitle;
     nsString errorMsgBody;
-    bundle->GetStringFromName(NS_LITERAL_STRING("nocachedbodybody").get(), getter_Copies(errorMsgBody));
-    bundle->GetStringFromName(NS_LITERAL_STRING("nocachedbodytitle").get(),  getter_Copies(errorMsgTitle));
+    bundle->GetStringFromName(MOZ_UTF16("nocachedbodybody"), getter_Copies(errorMsgBody));
+    bundle->GetStringFromName(MOZ_UTF16("nocachedbodytitle"), getter_Copies(errorMsgTitle));
     aMsgWindow->DisplayHTMLInMessagePane(errorMsgTitle, errorMsgBody, true);
   }
-  
+
   return NS_OK;
 }
 
