@@ -15,10 +15,10 @@
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 
-XPCOMUtils.defineLazyGetter(this, "PageMenu", function() {
+XPCOMUtils.defineLazyGetter(this, "PageMenuParent", function() {
   let tmp = {};
   Components.utils.import("resource://gre/modules/PageMenu.jsm", tmp);
-  return new tmp.PageMenu();
+  return new tmp.PageMenuParent();
 });
 
 function nsContextMenu(aXulMenu, aBrowser, aIsShift) {
@@ -39,8 +39,7 @@ nsContextMenu.prototype = {
     this.hasPageMenu = false;
     if (!aIsShift && this.browser.docShell.allowJavascript &&
         Services.prefs.getBoolPref("javascript.enabled"))
-      this.hasPageMenu = PageMenu.maybeBuildAndAttachMenu(this.target,
-                                                          aXulMenu);
+      this.hasPageMenu = PageMenuParent.buildAndAddToPopup(this.target, aXulMenu);
 
     this.isTextSelected = this.isTextSelection();
     this.isContentSelected = this.isContentSelection();
@@ -276,7 +275,8 @@ nsContextMenu.prototype = {
   },
 
   initSpellingItems: function() {
-    var canSpell = InlineSpellCheckerUI.canSpellCheck;
+    var canSpell = InlineSpellCheckerUI.canSpellCheck &&
+                   !InlineSpellCheckerUI.initialSpellCheckPending;
     var onMisspelling = InlineSpellCheckerUI.overMisspelling;
     var showUndo = InlineSpellCheckerUI.enabled &&
                    InlineSpellCheckerUI.canUndo();
@@ -472,8 +472,8 @@ nsContextMenu.prototype = {
         this.onTextInput           = true;
         this.possibleSpellChecking = true;
         InlineSpellCheckerUI.init(editingSession.getEditorForWindow(win));
-        var canSpell = InlineSpellCheckerUI.canSpellCheck;
         InlineSpellCheckerUI.initFromEvent(aRangeParent, aRangeOffset);
+        var canSpell = InlineSpellCheckerUI.canSpellCheck;
         this.showItem("spell-check-enabled", canSpell);
         this.showItem("spell-separator", canSpell);
         return;
