@@ -10,6 +10,7 @@ MOZ_APP_DISPLAYNAME=SeaMonkey
 MOZ_LDAP_XPCOM=1
 MOZ_CHROME_FILE_FORMAT=omni
 MOZ_COMPOSER=1
+MOZ_DISABLE_EXPORT_JS=1
 MOZ_SUITE=1
 MOZ_BRANDING_DIRECTORY=suite/branding/nightly
 MOZ_OFFICIAL_BRANDING_DIRECTORY=suite/branding/nightly
@@ -24,11 +25,13 @@ MAR_CHANNEL_ID=seamonkey-comm-central
 MOZ_HELP_VIEWER=1
 MOZ_MEDIA_NAVIGATOR=1
 MOZ_MORK=1
-MOZ_STATIC_BUILD_UNSUPPORTED=1
+MOZ_SAFE_BROWSING=1
 MOZ_SERVICES_COMMON=1
 MOZ_SERVICES_CRYPTO=1
 MOZ_SERVICES_FXACCOUNTS=1
 MOZ_SERVICES_SYNC=1
+MOZ_SERVICES_CLOUDSYNC=1
+MOZ_STATIC_BUILD_UNSUPPORTED=1
 MOZ_URL_CLASSIFIER=1
 MOZ_WEBGL_CONFORMANT=1
 MOZ_WEBM_ENCODER=1
@@ -42,5 +45,3 @@ MOZ_UA_BUILDID=20100101
 MOZ_APP_ID={92650c4d-4b8e-4d2a-b7eb-24ecf4f6b63a}
 MOZ_PROFILE_MIGRATOR=1
 MOZ_APP_STATIC_INI=1
-# Enable generational GC on desktop.
-JSGC_GENERATIONAL=1
