@@ -55,7 +55,6 @@ const kVcardFields =
           // Other > Notes
          ["Notes", "Notes"]];
 
-const kDefaultYear = 2000;
 var gEditCard;
 var gOnSaveListeners = [];
 var gOnLoadListeners = [];
@@ -356,7 +355,7 @@ function InitPhoneticFields()
     Services.prefs.getComplexValue("mail.addr_book.show_phonetic_fields", 
       Components.interfaces.nsIPrefLocalizedString).data;
 
-  // hide phonetic fields if indicated by the pref
+  // show phonetic fields if indicated by the pref
   if (showPhoneticFields == "true")
   {
     for (var i = kPhoneticFields.length; i-- > 0; )
@@ -449,6 +448,15 @@ function GetCardValues(cardproperty, doc)
   var birthday = doc.getElementById("Birthday");
   modifyDatepicker(birthday);
 
+  // Get the year first, so that the following month/day
+  // calculations can take leap years into account.
+  var year = cardproperty.getProperty("BirthYear", null);
+  var birthYear = doc.getElementById("BirthYear");
+  // set the year in the datepicker to the stored year
+  // if the year isn't present, default to 2000 (a leap year)
+  birthday.year = saneBirthYear(year);
+  birthYear.value = year;
+
   // get the month of the year (1 - 12)
   var month = cardproperty.getProperty("BirthMonth", null);
   if (month > 0 && month < 13)
@@ -463,14 +471,6 @@ function GetCardValues(cardproperty, doc)
   else
     birthday.dateField.value = null;
 
-  // get the year
-  var year = cardproperty.getProperty("BirthYear", null);
-  var birthYear = doc.getElementById("BirthYear");
-  // set the year in the datepicker to the stored year
-  // if the year isn't present, default to 2000 (a leap year)
-  birthday.year = year && year < 10000 && year > 0 ? year : kDefaultYear;
-  birthYear.value = year;
-
   // get the current age
   calculateAge(null, birthYear);
   // when the birth year changes, update the datepicker's year to the new value
