@@ -3,8 +3,10 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
+Components.utils.import("resource://gre/modules/Services.jsm");
 Components.utils.import("resource:///modules/folderUtils.jsm");
 Components.utils.import("resource:///modules/iteratorUtils.jsm");
+Components.utils.import("resource:///modules/mailServices.js");
 
 /**
  * interfaces
@@ -150,6 +152,9 @@ var gComposeRecyclingListener = {
     // We need to clear the identity popup menu in case the user will change them. It will be rebuilded later in ComposeStartup
     ClearIdentityListPopup(document.getElementById("msgIdentityPopup"));
 
+    // Stop listening to changes in the spell check dictionary.
+    document.removeEventListener("spellcheck-changed", updateDocumentLanguage);
+
     // Stop InlineSpellCheckerUI so personal dictionary is saved.
     // We need to do this before disabling the editor.
     EnableInlineSpellCheck(false);
@@ -863,6 +868,10 @@ function ComposeStartup(recycled, aParams)
     }
   }
 
+  // Set the document language to the preference as early as possible.
+  document.documentElement
+          .setAttribute("lang", getPref("spellchecker.dictionary"));
+
   var identityList = GetMsgIdentityElement();
 
   if (identityList)
@@ -947,7 +956,10 @@ function ComposeStartup(recycled, aParams)
     params.identity = identities.queryElementAt(0, Components.interfaces.nsIMsgIdentity);
   }
 
-  identityList.value = params.identity.key;
+  identityList.selectedItem =
+    identityList.getElementsByAttribute("identitykey", params.identity.key)[0];
+  if (params.composeFields.from)
+    identityList.value = MailServices.headerParser.parseDecodedHeader(params.composeFields.from)[0].toString();
   LoadIdentity(true);
   if (sMsgComposeService)
   {
@@ -1274,6 +1286,9 @@ function GenericSendMessage( msgType )
     if (msgCompFields)
     {
       Recipients2CompFields(msgCompFields);
+      var address = GetMsgIdentityElement().value;
+      address = MailServices.headerParser.makeFromDisplayAddress(address);
+      msgCompFields.from = MailServices.headerParser.makeMimeHeader(address, 1);
       var subject = GetMsgSubjectElement().value;
       msgCompFields.subject = subject;
       Attachments2CompFields(msgCompFields);
@@ -1826,6 +1841,10 @@ function ChangeLanguage(event)
   {
     spellChecker.SetCurrentDictionary(event.target.value);
 
+    // Update the document language as well.
+    // This is needed to synchronize the subject.
+    document.documentElement.setAttribute("lang", event.target.value);
+
     // now check the document and the subject over again with the new dictionary
     if (InlineSpellCheckerUI.enabled)
     {
@@ -1893,8 +1912,13 @@ function FillIdentityList(menulist)
     for (let i = 0; i < identities.length; i++)
     {
       let identity = identities[i];
-      let item = menulist.appendItem(identity.identityName, identity.key,
+      let address = MailServices.headerParser
+                                .makeMailboxObject(identity.fullName,
+                                                   identity.email).toString();
+      let item = menulist.appendItem(identity.identityName,
+                                     address,
                                      account.incomingServer.prettyName);
+      item.setAttribute("identitykey", identity.key);
       item.setAttribute("accountkey", account.key);
       if (i == 0)
       {
@@ -1905,13 +1929,6 @@ function FillIdentityList(menulist)
   }
 }
 
-function getCurrentIdentity()
-{
-  // fill in Identity combobox
-  var identityKey = GetMsgIdentityElement().value;
-  return gAccountManager.getIdentity(identityKey);
-}
-
 function getCurrentAccountKey()
 {
     // get the accounts key
@@ -1919,11 +1936,23 @@ function getCurrentAccountKey()
     return identityList.selectedItem.getAttribute("accountkey");
 }
 
+function getCurrentIdentityKey()
+{
+    // get the identity key
+    var identityList = GetMsgIdentityElement();
+    return identityList.selectedItem.getAttribute("identitykey");
+}
+
 function getIdentityForKey(key)
 {
     return gAccountManager.getIdentity(key);
 }
 
+function getCurrentIdentity()
+{
+  return getIdentityForKey(getCurrentIdentityKey());
+}
+
 function AdjustFocus()
 {
   var element = awGetInputElement(awGetNumberOfRecipients());
@@ -2369,7 +2398,9 @@ function LoadIdentity(startup)
     var prevIdentity = gCurrentIdentity;
 
     if (identityElement) {
-        var idKey = identityElement.value;
+        identityElement.value = identityElement.selectedItem.value;
+
+        var idKey = identityElement.selectedItem.getAttribute("identitykey");
         gCurrentIdentity = gAccountManager.getIdentity(idKey);
 
         let accountKey = null;
@@ -2889,10 +2920,30 @@ function AutoSave()
 
 function InitEditor(editor)
 {
+  // Set the eEditorMailMask flag to avoid using content prefs for the spell
+  // checker, otherwise the dictionary setting in preferences is ignored and
+  // the dictionary is inconsistent between the subject and message body.
+  var eEditorMailMask = Components.interfaces.nsIPlaintextEditor.eEditorMailMask;
+  editor.flags |= eEditorMailMask;
+  GetMsgSubjectElement().editor.flags |= eEditorMailMask;
+
   gMsgCompose.initEditor(editor, window.content);
   InlineSpellCheckerUI.init(editor);
   EnableInlineSpellCheck(getPref("mail.spellcheck.inline"));
   document.getElementById("menu_inlineSpellCheck").setAttribute("disabled", !InlineSpellCheckerUI.canSpellCheck);
+
+  // Listen for spellchecker changes, set the document language to the
+  // dictionary picked by the user via the right-click menu in the editor.
+  document.addEventListener("spellcheck-changed", updateDocumentLanguage);
+}
+
+/**
+ * The event listener for the "spellcheck-changed" event updates
+ * the document language.
+ */
+function updateDocumentLanguage(event)
+{
+  document.documentElement.setAttribute("lang", event.detail.dictionary);
 }
 
 function EnableInlineSpellCheck(aEnableInlineSpellCheck)
