@@ -3,6 +3,8 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
+Components.utils.import("resource:///modules/mailServices.js");
+
 //NOTE: gMessengerBundle must be defined and set or this Overlay won't work
 
 /**
@@ -130,18 +132,20 @@ function FillMailContextMenu(aTarget)
 
   ShowMenuItem("mailContext-editAsNew", showMailItems && oneOrMore);
   ShowMenuItem("mailContext-replySender", showMailItems && single);
+  ShowMenuItem("mailContext-replyList",
+               showMailItems && single && !isNewsgroup && IsListPost());
   ShowMenuItem("mailContext-replyNewsgroup",
                showMailItems && single && isNewsgroup);
   ShowMenuItem("mailContext-replySenderAndNewsgroup",
                showMailItems && single && isNewsgroup);
-  ShowMenuItem("mailContext-archive", showMailItems && oneOrMore &&
-               gFolderDisplay.canArchiveSelectedMessages);
   ShowMenuItem("mailContext-replyAll", showMailItems && single);
   ShowMenuItem("mailContext-forward", showMailItems && single);
   ShowMenuItem("mailContext-forwardAsAttachment",
                showMailItems && (numSelected > 1));
   ShowMenuItem("mailContext-copyMessageUrl",
                showMailItems && single && isNewsgroup);
+  ShowMenuItem("mailContext-archive", showMailItems && oneOrMore &&
+               gFolderDisplay.canArchiveSelectedMessages);
 
   // Set up the move menu. We can't move from newsgroups.
   // Disable move if we can't delete message(s) from this folder.
@@ -433,28 +437,40 @@ function EditContact(aEmailAddressNode)
   }
 }
 
-// SendMailToNode takes the email address title button, extracts
-// the email address we stored in there and opens a compose window
-// with that address
-function SendMailToNode(emailAddressNode)
+/**
+ * SendMailToNode takes the email address title button, extracts the email address
+ * we stored in there and opens a compose window with that address.
+ *
+ * @param addressNode  a node which has a "fullAddress" attribute
+ * @param aEvent       the event object when user triggers the menuitem
+ */
+function SendMailToNode(emailAddressNode, aEvent)
 {
   if (emailAddressNode)
-    SendMailTo(emailAddressNode.getAttribute("fullAddress"));
+    SendMailTo(emailAddressNode.getAttribute("fullAddress"), aEvent);
 }
 
-function SendMailTo(fullAddress)
+function SendMailTo(fullAddress, aEvent)
 {
-  var fields = Components.classes["@mozilla.org/messengercompose/composefields;1"].createInstance(Components.interfaces.nsIMsgCompFields);
-  var params = Components.classes["@mozilla.org/messengercompose/composeparams;1"].createInstance(Components.interfaces.nsIMsgComposeParams);
-  if (fields && params)
-  {
-    fields.to = fullAddress;
-    params.type = Components.interfaces.nsIMsgCompType.New;
-    params.format = Components.interfaces.nsIMsgCompFormat.Default;
-    params.identity = accountManager.getFirstIdentityForServer(GetLoadedMsgFolder().server);
-    params.composeFields = fields;
-    msgComposeService.OpenComposeWindowWithParams(null, params);
-  }
+  var fields = Components.classes["@mozilla.org/messengercompose/composefields;1"]
+                         .createInstance(Components.interfaces.nsIMsgCompFields);
+  var params = Components.classes["@mozilla.org/messengercompose/composeparams;1"]
+                         .createInstance(Components.interfaces.nsIMsgComposeParams);
+
+  var headerParser = MailServices.headerParser;
+  var addresses = headerParser.makeFromDisplayAddress(fullAddress);
+  fields.to = headerParser.makeMimeHeader(addresses, 1);
+  params.type = Components.interfaces.nsIMsgCompType.New;
+
+  // If aEvent is passed, check if Shift key was pressed for composition in
+  // non-default format (HTML vs. plaintext).
+  params.format = (aEvent && aEvent.shiftKey) ?
+    Components.interfaces.nsIMsgCompFormat.OppositeOfDefault :
+    Components.interfaces.nsIMsgCompFormat.Default;
+
+  params.identity = accountManager.getFirstIdentityForServer(GetLoadedMsgFolder().server);
+  params.composeFields = fields;
+  MailServices.compose.OpenComposeWindowWithParams(null, params);
 }
 
 // CopyEmailAddress takes the email address title button, extracts
@@ -527,12 +543,12 @@ function OpenMessageForMessageId(messageId)
 
     messageHeader = SearchForMessageIdInSubFolder(startServer.rootFolder, messageId);
 
-    for (var i = 0; i < allServers.Count() && !messageHeader; i++)
+    for (var i = 0; i < allServers.length && !messageHeader; i++)
     {
-      var currentServer = allServers.GetElementAt(i);
-      if ((currentServer instanceof Components.interfaces.nsIMsgIncomingServer) &&
-          startServer != currentServer && currentServer.canSearchMessages &&
-          !currentServer.isDeferredTo)
+      var currentServer =
+        allServers.queryElementAt(i, Components.interfaces.nsIMsgIncomingServer);
+      if (currentServer && startServer != currentServer &&
+          currentServer.canSearchMessages && !currentServer.isDeferredTo)
       {
         messageHeader = SearchForMessageIdInSubFolder(currentServer.rootFolder, messageId);
       }
@@ -543,7 +559,7 @@ function OpenMessageForMessageId(messageId)
   // if message id was found open corresponding message
   // else show error message
   if (messageHeader)
-    OpenMessageByHeader(messageHeader, pref.getBoolPref("mailnews.messageid.openInNewWindow"));
+    OpenMessageByHeader(messageHeader, Services.prefs.getBoolPref("mailnews.messageid.openInNewWindow"));
   else
   {
     var messageIdStr = "<" + messageId + ">";
